/* global addEventListener */

import { visualizeAgents } from "./vis";
import { escape } from "sqlstring";
import Gateway from "sql-gateway";

const getUA = require("ua-parser-js");

async function worker(request) {
  const STAT_SUFFIX = "/stat";
  const STAT_REGEX = /\/stat+/;
  const STATIC_ASSET_ROUTE = "static";
  const gateway = new Gateway(
    "db.averyharnish.com&hCMCQ2Cq6iiqFFQjtnFKDsWMKWmrmw9kI0RQdo3DvaqXNGB6u298Lhiys39t8NY1",
    "postgres",
    "cf"
  );
  let canonicalUrl = new URL(request.url).href.replace(/\/+$/, "");
  let response;
  if (canonicalUrl.endsWith(STAT_SUFFIX)) {
    canonicalUrl = canonicalUrl.slice(0, -1 * STAT_SUFFIX.length);
    let osResponse = await gateway.execute(
      `SELECT os, COUNT(*) FROM user_agents WHERE route = ${escape(
        canonicalUrl
      )} GROUP BY os;`
    );
    let browserResponse = await gateway.execute(
      `SELECT browser, COUNT(*) FROM user_agents WHERE route = ${escape(
        canonicalUrl
      )} GROUP BY browser;`
    );
    let mostRecent = await gateway.execute(
      `SELECT browser, os from user_agents WHERE created_at IS NOT NULL AND route = ${escape(
        canonicalUrl
      )} AND browser IS NOT NULL AND os IS NOT NULL ORDER BY created_at DESC LIMIT 1;`
    );
    let mostRecentData;
    let osData;
    let browserData;
    try {
      mostRecentData = JSON.parse(await mostRecent.text());
      osData = JSON.parse(await osResponse.text());
      browserData = JSON.parse(await browserResponse.text());
    } catch (err) {
      return osResponse;
    }
    if (
      osData["error"] === "" &&
      browserData["error"] === "" &&
      mostRecentData["error"] === ""
    ) {
      response = await visualizeAgents(canonicalUrl, {
        os: osData,
        browser: browserData,
        mostRecent: mostRecentData
      });
    } else {
      console.error(
        `ERROR: ${browserData["error"]}\nERROR: ${osData["error"]}\nERROR: ${
          mostRecentData["error"]
        }`
      );
      response = Response.redirect(canonicalUrl, 302);
    }
  }

  let pathComponents = new URL(request.url).pathname.split("/");
  if (
    pathComponents.length == 1 ||
    (pathComponents.length > 1 &&
      pathComponents[1] != STATIC_ASSET_ROUTE &&
      !request.url.endsWith(STAT_SUFFIX))
  ) {
    let ua = getUA(request.headers.get("user-agent"));
    await gateway.execute(
      `INSERT INTO user_agents (route, os, browser) VALUES (${escape(
        canonicalUrl
      )}, ${escape(ua["os"]["name"])}, ${escape(ua["browser"]["name"])});`
    );
  }
  if (!response) {
    response = await fetch(request);
  }
  return response;
}

addEventListener("fetch", event => {
  event.respondWith(worker(event.request));
});
