const render = (url, data, osData, browserData, colors) => {
  return `<!doctype html>
  <html>
  <head>
    <meta charset="utf-8">
    <title>User Agent Stats</title>
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <link rel="stylesheet" type="text/css" href="//fonts.googleapis.com/css?family=Open+Sans" />
    <link rel="icon" type="image/x-icon" href="https://cloudflare.com/favicon.ico">
    <style>
      body {
        margin: 0;
      }

      /* Style the header */
      .header {
          background-color: #424242;
          padding: 10px;
          text-align: center;
          font-family: "Open Sans";
          color: white;
      }
      #content {
        margin-top: 50px;
        min-height: calc(100vh - 275px);
      }
      
      footer {
        background-color: #424242;
        text-align: center;
        font-family: "Open Sans";
        height: 53px;
        color: white;
      }
      </style>
  </head>
  
  <body>
    <!--[if lte IE 9]>
      <p class="browserupgrade">You are using an <strong>outdated</strong> browser. Please <a href="https://browsehappy.com/">upgrade your browser</a> to improve your experience and security.</p>
    <![endif]-->
    <div class="header">
      <h1>Stats for <a href="${url}" style="color: #FF7900">${url}</a></h1>
      <h3>The most recent visitor using a known browser/os was using ${
        data["mostRecent"]["rows"][0][0]
      } on a machine running ${data["mostRecent"]["rows"][0][1]}.</h2>
    </div>
    <div id="content" style="padding: 10px 30px 0px;">
      <div style="float: left; width: 50%; height: 100px;">
        <canvas id="osChart"></canvas>
      </div>
      <div style="float: right; width: 50%; height: 100px;">
        <canvas id="browserChart"></canvas>
      </div>
    </div>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/2.7.2/Chart.bundle.min.js"></script>
    <script>
      var osCtx = document.getElementById("osChart").getContext('2d');
      var myChart = new Chart(osCtx, {
        type: 'pie',
        data: {
            labels: [${osData["names"]}],
            datasets: [{
                label: '# of Visits',
                data: [${osData["data"]}],
                borderWidth: 1,
                backgroundColor: [${colors["os"]}]
            }]
        },
        options: {
          title: {
            display: true,
            text: 'Operating Systems',
            position: 'top'
          },
          legend: {
            display: true,
            position: 'left'
          }
        }
      });
    </script>
    <script>
      var browserCtx = document.getElementById("browserChart").getContext('2d');
      var myChart = new Chart(browserCtx, {
        type: 'pie',
        data: {
          labels: [${browserData["names"]}],
          datasets: [{
              label: '# of Visits',
              data: [${browserData["data"]}],
              borderWidth: 1,
              backgroundColor: [${colors["browser"]}]
          }]
        },
        options: {
          title: {
            display: true,
            text: 'Browsers',
            position: 'top'
          },
          legend: {
            display: true,
            position: 'left'
          }
        }
      });
    </script>
    <footer>
        <p style="padding-top:15px;">Created with <a style="color: #FF7900" href="https://cloudflareworkers.com">Cloudflare Workers</a>.</p>
    </footer>
  </body>
  
  </html>`;
};

export default render;
