const palette = require("google-palette");
import render from "./stat.html";

function _getNamesAndData(input) {
  let data = [];
  let names = "";
  let unknownCount = 0;
  input.forEach(row => {
    if (!row[0]) {
      unknownCount += parseInt(row[1], 10);
    } else {
      names += `"${row[0]}",`;
      data.push(parseInt(row[1], 10));
    }
  });
  if (unknownCount > 0) {
    names += `"Unknown",`;
    data.push(unknownCount);
  }
  return { names: names.slice(0, -1), data: data };
}

function _getColors(osLength, browserLength) {
  const seq = palette("tol-rainbow", osLength + browserLength);
  let osOut = "";
  let browserOut = "";
  let osColors = seq.slice(0, osLength);
  let browserColors = seq.slice(osLength, browserLength + osLength);
  osColors.forEach(col => {
    osOut += `"#${col}",`;
  });
  browserColors.forEach(col => {
    browserOut += `"#${col}",`;
  });
  return { os: osOut.slice(0, -1), browser: browserOut.slice(0, -1) };
}

async function visualizeAgents(url, data) {
  let osData = _getNamesAndData(data["os"]["rows"]);
  let browserData = _getNamesAndData(data["browser"]["rows"]);
  let colors = _getColors(osData.data.length, browserData.data.length);
  let body = render(url, data, osData, browserData, colors);
  return new Response(body, {
    headers: { "Content-Type": "text/html; charset=utf-8" }
  });
}

export { visualizeAgents };
